@@ -6,6 +6,7 @@ from cStringIO import StringIO
 from csvkit import CSVKitReader, CSVKitWriter
 from csvkit import sniffer
 from csvkit import typeinference
+from csvkit.cli import parse_column_identifiers
 
 class InvalidType(object):
     """
@@ -21,7 +22,7 @@ class Column(list):
         """
         Construct a column from a sequence of values.
         
-        If normal_type is not None, inference will be skipped and values assumed to have already been normalized.
+        If normal_type is not InvalidType, inference will be skipped and values assumed to have already been normalized.
         """
         if normal_type != InvalidType:
             t = normal_type
@@ -179,9 +180,14 @@ class Table(list):
         return row_data
 
     @classmethod
-    def from_csv(cls, f, name='from_csv_table', snifflimit=None, **kwargs):
+    def from_csv(cls, f, name='from_csv_table', snifflimit=None, column_ids=None, **kwargs):
         """
         Creates a new Table from a file-like object containing CSV data.
+
+        Note: the column_ids argument will cause only those columns with a matching identifier
+        to be parsed, type inferred, etc. However, their order/index property will reflect the
+        original data (e.g. column 8 will still be "order" 7, even if it's the third column
+        in the resulting Table.
         """
         # This bit of nonsense is to deal with "files" from stdin,
         # which are not seekable and thus must be buffered
@@ -198,21 +204,27 @@ class Table(list):
         reader = CSVKitReader(f, dialect=dialect, **kwargs)
 
         headers = reader.next()
-
-        data_columns = [[] for c in headers] 
+        
+        if column_ids:
+            column_ids = parse_column_identifiers(column_ids, headers)
+            headers = [headers[c] for c in column_ids]
+        else:
+            column_ids = range(len(headers))
+        
+        data_columns = [[] for c in headers]
 
         for row in reader:
             for i, d in enumerate(row):
                 try:
-                    data_columns[i].append(d.strip())
+                    data_columns[i].append(row[column_ids[i]].strip())
                 except IndexError:
                     # Non-rectangular data is truncated
                     break
 
         columns = []
 
-        for i, c in enumerate(data_columns): 
-            columns.append(Column(i, headers[i], c))
+        for i, c in enumerate(data_columns):
+            columns.append(Column(column_ids[i], headers[i], c))
 
         return Table(columns, name=name)
 
@@ -248,3 +260,4 @@ class Table(list):
 
         writer = CSVKitWriter(output, **kwargs)
         writer.writerows(rows)
+
